Algorithms
============

Algorithms have as input data (typically as a QCoDeS dataset or a numpy array) and parameters of the algorithm. 
The output is a dictionary with the main results as keys of the dictionary.

Example notebooks
-----------------

Most of the algorithms are documented in the `Example notebooks`_ section.


Source code
-----------

The source code for the algoritms can be found below:

.. doccommand:
   See  https://stackoverflow.com/questions/20569011/python-sphinx-autosummary-automated-listing-of-member-functions
   See https://sphinx-automodapi.readthedocs.io/en/latest/automodsumm.html

.. autosummary::
   qtt.algorithms.anticrossing
   qtt.algorithms.awg_to_plunger
   qtt.algorithms.bias_triangles
   qtt.algorithms.chargesensor
   qtt.algorithms.coulomb
   qtt.algorithms.fitting
   qtt.algorithms.functions
   qtt.algorithms.gatesweep
   qtt.algorithms.generic
   qtt.algorithms.images
   qtt.algorithms.misc
   qtt.algorithms.ohmic
   qtt.algorithms.onedot
   qtt.algorithms.pat_fitting
   qtt.algorithms.random_telegraph_signal
   qtt.algorithms.tunneling
   

Back to the :doc:`main page <index>`.
